@@ -11,11 +11,23 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <string.h>
+
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkcolorbutton.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtksizegroup.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkvbox.h>
+
 #include <gconf/gconf-client.h>
+#include <libgnomeui/gnome-help.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
-#include <string.h>
 
 #include "global.h"
 
@@ -250,7 +262,7 @@ color_picker_set_cb(GtkColorButton *color_picker, gpointer data)
 		prop_type = PROP_CPU;
 	else if (strstr(gconf_path, "memload"))
 		prop_type = PROP_MEM;
-	else if (strstr(gconf_path, "netload"))
+	else if (strstr(gconf_path, "netload2"))
 		prop_type = PROP_NET;
 	else if (strstr(gconf_path, "swapload"))
 		prop_type = PROP_SWAP;
@@ -322,7 +334,7 @@ add_color_selector(GtkWidget *page, gchar *name, gchar *gconf_path, MultiloadApp
 static void
 fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 {
-	GtkWidget *notebook, *page;
+	GtkWidget *page;
 	GtkWidget *hbox, *vbox;
 	GtkWidget *categories_vbox;
 	GtkWidget *category_vbox;
@@ -589,10 +601,10 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_box_pack_start (GTK_BOX (hbox), control_vbox, TRUE, TRUE, 0);
 	gtk_widget_show (control_vbox);
 
-	notebook = gtk_notebook_new();
-	gtk_container_add (GTK_CONTAINER (control_vbox), notebook);
+	ma->notebook = gtk_notebook_new();
+	gtk_container_add (GTK_CONTAINER (control_vbox), ma->notebook);
 	
-	page = add_page(notebook,  _("Processor"));
+	page = add_page(ma->notebook,  _("Processor"));
 	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
 	add_color_selector(page, _("_User"), "cpuload_color0", ma);
 	add_color_selector(page, _("S_ystem"), "cpuload_color1", ma);
@@ -600,7 +612,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	add_color_selector(page, _("I_OWait"), "cpuload_color3", ma);
 	add_color_selector(page, _("I_dle"), "cpuload_color4", ma);
 	
-	page = add_page(notebook,  _("Memory"));
+	page = add_page(ma->notebook,  _("Memory"));
 	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
 	add_color_selector(page, _("_User"), "memload_color0", ma);
 	add_color_selector(page, _("Sh_ared"), "memload_color1", ma);
@@ -608,25 +620,24 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	add_color_selector (page, _("Cach_ed"), "memload_color3", ma);
 	add_color_selector(page, _("F_ree"), "memload_color4", ma);
 	
-	page = add_page(notebook,  _("Network"));
+	page = add_page(ma->notebook,  _("Network"));
 	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
-	add_color_selector (page, _("_SLIP"), "netload_color0", ma);
-	add_color_selector(page, _("PL_IP"), "netload_color1", ma);
-	add_color_selector (page, _("_Ethernet"), "netload_color2", ma);
-	add_color_selector (page, _("Othe_r"), "netload_color3", ma);
-	add_color_selector(page, _("_Background"), "netload_color4", ma);
+	add_color_selector (page, _("_In"), "netload2_color0", ma);
+	add_color_selector(page, _("_Out"), "netload2_color1", ma);
+	add_color_selector (page, _("_Local"), "netload2_color2", ma);
+	add_color_selector(page, _("_Background"), "netload2_color3", ma);
 	
-	page = add_page(notebook,  _("Swap Space"));
+	page = add_page(ma->notebook,  _("Swap Space"));
 	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
 	add_color_selector(page, _("_Used"), "swapload_color0", ma);
 	add_color_selector(page, _("_Free"), "swapload_color1", ma);
 	
-	page = add_page(notebook,  _("Load"));
+	page = add_page(ma->notebook,  _("Load"));
 	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
 	add_color_selector(page, _("_Average"), "loadavg_color0", ma);
 	add_color_selector(page, _("_Background"), "loadavg_color1", ma);
 
-	page = add_page (notebook, _("Harddisk"));
+	page = add_page (ma->notebook, _("Harddisk"));
 	gtk_container_set_border_width (GTK_CONTAINER (page), 12);
 	add_color_selector (page, _("_Read"), "diskload_color0", ma);
 	add_color_selector (page, _("_Write"), "diskload_color1", ma);
@@ -642,13 +653,15 @@ multiload_properties_cb (BonoboUIComponent *uic,
 			 const char        *name)
 {
 	GtkWidget *dialog = NULL;
-	
+
 	if (ma->prop_dialog) {
 		dialog = ma->prop_dialog;
 
 		gtk_window_set_screen (GTK_WINDOW (dialog),
 				gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
 
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (ma->notebook),
+					       ma->last_clicked);
 		gtk_window_present (GTK_WINDOW (dialog));
 		return;
 	}
@@ -674,8 +687,9 @@ multiload_properties_cb (BonoboUIComponent *uic,
 			 G_CALLBACK(properties_close_cb), ma);
 
 	ma->prop_dialog = dialog;
-	
+
 	gtk_widget_show_all(dialog);
-	
-	return;
+
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (ma->notebook),
+				       ma->last_clicked);
 }
