@@ -67,6 +67,9 @@ stickynote_show_notes (gboolean visible)
 	StickyNote *note;
 	GList *l;
 
+    if (stickynotes->visible == visible) return;
+    stickynotes->visible = visible;
+
 	for (l = stickynotes->notes; l; l = l->next)
 	{
 		note = l->data;
@@ -74,6 +77,12 @@ stickynote_show_notes (gboolean visible)
 	}
 }
 
+static void
+stickynote_toggle_notes_visible ()
+{
+    stickynote_show_notes(!stickynotes->visible);
+}
+
 /* Applet Callback : Mouse button press on the applet. */
 gboolean
 applet_button_cb (GtkWidget         *widget,
@@ -87,7 +96,7 @@ applet_button_cb (GtkWidget         *widget,
 	}
 	else if (event->button == 1)
 	{
-		stickynote_show_notes (TRUE);
+		stickynote_toggle_notes_visible ();
 		return TRUE;
 	}
 
@@ -140,6 +149,7 @@ static GdkFilterReturn desktop_window_event_filter (GdkXEvent *xevent,
 	    (((XEvent*)xevent)->xproperty.atom == gdk_x11_get_xatom_by_name ("_NET_WM_USER_TIME"))) { 
 		stickynote_show_notes (FALSE);
 	} 
+	return GDK_FILTER_CONTINUE;
 }
 
 void install_check_click_on_desktop (void)
@@ -283,7 +293,10 @@ void menu_hide_notes_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const
 /* Menu Callback : Destroy all sticky notes */
 void menu_destroy_all_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname)
 {
-	GladeXML *glade = glade_xml_new(GLADE_PATH, "delete_all_dialog", NULL);
+	GtkBuilder *builder;
+
+	builder = gtk_builder_new ();
+  	gtk_builder_add_from_file (builder, BUILDER_PATH, NULL);
 
 	if (applet->destroy_all_dialog != NULL) {
 		gtk_window_set_screen (GTK_WINDOW (applet->destroy_all_dialog),
@@ -293,9 +306,9 @@ void menu_destroy_all_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, cons
 		return;
 	}
 	
-	applet->destroy_all_dialog = glade_xml_get_widget(glade, "delete_all_dialog");
+	applet->destroy_all_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "delete_all_dialog"));
 
-	g_object_unref (glade);
+	g_object_unref (builder);
 
 	g_signal_connect (applet->destroy_all_dialog, "response",
 			  G_CALLBACK (destroy_all_response_cb),
@@ -365,7 +378,7 @@ menu_about_cb (BonoboUIComponent *uic,
 		"authors",	authors,
 		"documenters",	documenters,
 		"translator-credits",	_("translator-credits"),
-		"logo-icon-name",	"stock_notes",
+		"logo-icon-name",	"gnome-sticky-notes-applet",
 		NULL);
 }
 
